From: Chintan Pandya <cpandya@codeaurora.org>
To: Frank Rowand <frowand.list@gmail.com>, Rob Herring <robh+dt@kernel.org>
Cc: devicetree@vger.kernel.org, linux-kernel@vger.kernel.org
Subject: Re: [PATCH] of: cache phandle nodes to decrease cost of of_find_node_by_phandle()
Date: Wed, 7 Feb 2018 18:14:23 +0530 [thread overview]
Message-ID: <1768c791-7456-c1fe-578b-f6245e79746f@codeaurora.org> (raw)
In-Reply-To: <0a178f4b-75fe-0564-7b0e-596f52fca1dc@codeaurora.org>
On 2/5/2018 5:53 PM, Chintan Pandya wrote:
>
>>
>> My question was trying to determine whether the numbers reported above
>> are for a debug configuration or a production configuration.
> My reported numbers are from debug configuration.
>
>> not a production configuration, I was requesting the numbers for a
>> production configuration.
> I'm working on it. But please expect some delay in my response for this.
> As I mentioned earlier, I need to work with few teams to get these numbers.
>
>
>> show a significant boot time reduction from the patch then there is
>> less justification for adding complexity to the existing code. I
>> prefer to use simpler data structures and algorithms __if__ extra
>> complexity does not provide any advantage. The balance between
>> complexity and benefits is a core software engineering issue.
>>
> Ok
Avg Kernel boot time comparison in production set up:
[0] Base: 4519ms
[1] 4115ms (~400ms improvement)
[2] 4115ms (~400ms improvement)
[3] 4177ms (~340ms improvement)
Full data:
[1] 1024 sized pre-populated cache
ITR-1 ITR-2 ITR-3 ITR-4 Avg
4115 4123 4124 4107 4115
[2] Dynamic sized cache allocation/free
ITR-1 ITR-2 ITR-3 ITR-4 Avg
4122 4131 4106 4118 4115
[3] Fixed 64 sized cache
ITR-1 ITR-2 ITR-3 ITR-4 Avg
4153 4186 4198 4181 4177
[1] is my experimental patch and dirty enough to not get merged
anywhere. So, I will not push it.
Chintan
--
Qualcomm India Private Limited, on behalf of Qualcomm Innovation Center,
Inc. is a member of the Code Aurora Forum, a Linux Foundation
Collaborative Project
next prev parent reply other threads:[~2018-02-07 12:44 UTC|newest]
Thread overview: 23+ messages / expand[flat|nested] mbox.gz Atom feed top
2018-01-31 20:05 frowand.list
2018-01-31 20:10 ` Frank Rowand
2018-01-31 21:43 ` Frank Rowand
2018-02-01 14:24 ` Rob Herring
2018-02-01 14:26 ` Rob Herring
2018-02-01 21:09 ` Frank Rowand
2018-02-02 3:45 ` Rob Herring
2018-02-02 22:34 ` Frank Rowand
2018-02-02 5:53 ` Chintan Pandya
2018-02-03 3:55 ` Frank Rowand
2018-02-01 6:45 ` Chintan Pandya
2018-02-01 8:59 ` Frank Rowand
2018-02-01 10:31 ` Chintan Pandya
2018-02-01 19:10 ` Frank Rowand
2018-02-02 5:59 ` Chintan Pandya
2018-02-02 21:26 ` Frank Rowand
2018-02-05 12:23 ` Chintan Pandya
2018-02-07 12:44 ` Chintan Pandya [this message]
2018-02-07 20:09 ` Frank Rowand
2018-02-01 14:34 ` Rob Herring
2018-02-01 21:13 ` Frank Rowand
-- strict thread matches above, loose matches on Subject: below --
2018-01-31 20:02 frowand.list
2018-01-31 20:07 ` Frank Rowand
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1768c791-7456-c1fe-578b-f6245e79746f@codeaurora.org \
--to=cpandya@codeaurora.org \
--cc=devicetree@vger.kernel.org \
--cc=frowand.list@gmail.com \
--cc=linux-kernel@vger.kernel.org \
--cc=robh+dt@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®